@@ -1,11 +1,11 @@
 from pydantic import BaseModel, Field
-from typing import List, Dict
+from typing import List, Dict, Any
 
 
 class TaskConfigurationSchema(BaseModel):
     task_input: List[Any] = Field(title="task_input",
-                                   description="The input for the task",
-                                   default=[])
+                                  description="The input for the task",
+                                  default=[])
     detail: List[Dict] = Field(title="detail",
                                description="Details pertaining to the task",
                                default=[])
